@@ -53,6 +53,7 @@ def print_photo_info(
                 "date_modified",
                 "portrait",
                 "screenshot",
+                "screen_recording",
                 "slow_mo",
                 "time_lapse",
                 "hdr",
@@ -98,6 +99,7 @@ def print_photo_info(
                     date_modified_iso,
                     p.portrait,
                     p.screenshot,
+                    p.screen_recording,
                     p.slow_mo,
                     p.time_lapse,
                     p.hdr,
